.. hoshi documentation master file, created by
   sphinx-quickstart on Wed Jul 27 23:12:58 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


hoshi
=====

.. include:: ../README.rst
    :start-after: inclusion-marker-do-not-remove

.. raw:: latex

       \vspace*{\fill}

.. raw:: latex

      \clearpage


Documentation
-------------

.. toctree::
   :maxdepth: 3

   i18n
   installation
   usage
   api/index


.. only:: html

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
